# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .adm_channel import *
from .apns_channel import *
from .apns_sandbox_channel import *
from .apns_voip_channel import *
from .apns_voip_sandbox_channel import *
from .app import *
from .baidu_channel import *
from .email_channel import *
from .event_stream import *
from .gcm_channel import *
from .sms_channel import *
from ._inputs import *
from . import outputs

def _register_module():
    import pulumi
    from .. import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "aws:pinpoint/admChannel:AdmChannel":
                return AdmChannel(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:pinpoint/apnsChannel:ApnsChannel":
                return ApnsChannel(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:pinpoint/apnsSandboxChannel:ApnsSandboxChannel":
                return ApnsSandboxChannel(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:pinpoint/apnsVoipChannel:ApnsVoipChannel":
                return ApnsVoipChannel(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:pinpoint/apnsVoipSandboxChannel:ApnsVoipSandboxChannel":
                return ApnsVoipSandboxChannel(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:pinpoint/app:App":
                return App(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:pinpoint/baiduChannel:BaiduChannel":
                return BaiduChannel(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:pinpoint/emailChannel:EmailChannel":
                return EmailChannel(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:pinpoint/eventStream:EventStream":
                return EventStream(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:pinpoint/gcmChannel:GcmChannel":
                return GcmChannel(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:pinpoint/smsChannel:SmsChannel":
                return SmsChannel(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("aws", "pinpoint/admChannel", _module_instance)
    pulumi.runtime.register_resource_module("aws", "pinpoint/apnsChannel", _module_instance)
    pulumi.runtime.register_resource_module("aws", "pinpoint/apnsSandboxChannel", _module_instance)
    pulumi.runtime.register_resource_module("aws", "pinpoint/apnsVoipChannel", _module_instance)
    pulumi.runtime.register_resource_module("aws", "pinpoint/apnsVoipSandboxChannel", _module_instance)
    pulumi.runtime.register_resource_module("aws", "pinpoint/app", _module_instance)
    pulumi.runtime.register_resource_module("aws", "pinpoint/baiduChannel", _module_instance)
    pulumi.runtime.register_resource_module("aws", "pinpoint/emailChannel", _module_instance)
    pulumi.runtime.register_resource_module("aws", "pinpoint/eventStream", _module_instance)
    pulumi.runtime.register_resource_module("aws", "pinpoint/gcmChannel", _module_instance)
    pulumi.runtime.register_resource_module("aws", "pinpoint/smsChannel", _module_instance)

_register_module()
